@@ -42,7 +42,15 @@ def match_sig(refFile=None,testFile=None,outFile=None,audioType=0):
     outStruct = get_none_data_of_ctypes_(outlen)
     if refsamplerate != testsamplerate :
         raise TypeError('Different format of ref and test files!')
-    mydll = ctypes.windll.LoadLibrary(sys.prefix + '/matchsig.dll')
+
+    import platform
+    mydll = None
+    cur_paltform = platform.platform().split('-')[0]
+    if cur_paltform == 'Windows':
+        mydll = ctypes.windll.LoadLibrary(sys.prefix + '/matchsig.dll')
+    if cur_paltform == 'macOS':
+        mydll = CDLL(sys.prefix + '/matchsig.dylib')
+
     mydll.matchsig_2.argtypes = [POINTER(emxArray_real_T), POINTER(emxArray_real_T), POINTER(emxArray_real_T),c_double,c_double,
                                      POINTER(c_double), POINTER(c_double)]
     delay, err = c_double(0.0), c_double(0.0)
