@@ -19,7 +19,15 @@ def cal_snr_transient(refFile=None, noisetFile=None, testFile=None):
     noiseStruct,noisesamplerate,_ = get_data_of_ctypes_(noisetFile,True)
     if refsamplerate != testsamplerate or refsamplerate!= noisesamplerate:
         raise TypeError('Different format of ref and test files!')
-    mydll = ctypes.windll.LoadLibrary(sys.prefix + '/snr_transient.dll')
+
+    import platform
+    mydll = None
+    cur_paltform = platform.platform().split('-')[0]
+    if cur_paltform == 'Windows':
+        mydll = ctypes.windll.LoadLibrary(sys.prefix + '/snr_transient.dll')
+    if cur_paltform == 'macOS':
+        mydll = CDLL(sys.prefix + '/snr_transient.dylib')
+
     mydll.SNR_transient.argtypes = [POINTER(emxArray_real_T),POINTER(emxArray_real_T),POINTER(emxArray_real_T),c_double, POINTER(c_double),POINTER(c_double),POINTER(c_double)]
     snr_1,snr_2,err = c_double(0.0),c_double(0.0),c_double(0.0)
     mydll.SNR_transient(byref(refstruct),byref(noiseStruct),byref(teststruct),c_double(refsamplerate),byref(snr_1),byref(snr_2),byref(err))
