@@ -23,6 +23,7 @@ from .FUNCTION.audioFunction import isSlience,audioFormat
 from .AEC_MOS.aecmos import cal_aec_mos
 from .MOS_INFER.run_predict import cal_mos_infer
 from .Noise_Suppression.noiseFuction import  cal_noise_Supp
+from .CLIPPING_DETECTION.audio_clip_detection import cal_clip_index
 from operator import methodcaller
 from .computeAudioQuality.mainProcess import computeAudioQuality
 
@@ -34,7 +35,7 @@ def compute_audio_quality(metrics,testFile=None,refFile=None,micFile=None,cleFil
     """
     :param metrics: G160/P563/POLQA/PESQ/STOI/STI/PEAQ/SDR/SII/LOUDNESS/MUSIC/MATCH/
                     TRANSIENT/GAINTABLE/ATTACKRELEASE/MUSICSTA/AGCDELAY/MATCHAEC/
-                    ERLE/SLIENCE/FORMAT/AECMOS/AIMOS/TRMS/ARMS/NOISE，必选项
+                    ERLE/SLIENCE/FORMAT/AECMOS/AIMOS/TRMS/ARMS/NOISE/CLIP，必选项
     # G160 无采样率限制；  WAV/PCM输入 ；三端输入: clean、ref、test；无时间长度要求；
     # P563 8000hz(其他采样率会强制转换到8khz)；  WAV/PCM输入 ；单端输入: test；时长 < 20s；
     # POLQA 窄带模式  8k  超宽带模式 48k ；WAV/PCM输入 ；双端输入：ref、test；时长 < 20s；
@@ -59,6 +60,7 @@ def compute_audio_quality(metrics,testFile=None,refFile=None,micFile=None,cleFil
     # TRMS 无采样率限制 WAV/PCM输入 ；单端输入：test；无时间长度要求；
     # ARMS 无采样率限制 WAV/PCM输入 ；单端输入：test；无时间长度要求；
     # NOISE 无采样率限制 WAV/PCM输入 ；双端输入：ref、test；无时间长度要求；
+    # CLIP 无采样率限制 WAV/PCM输入 ；单端输入：test；无时间长度要求；
     不同指标输入有不同的采样率要求，如果传入的文件不符合该指标的要求，会自动变采样到合法的区间
     :param testFile: 被测文件，必选项
     :param refFile:  参考文件，可选项，全参考指标必选，比如POLQA/PESQ/PEAQ
