@@ -37,6 +37,23 @@ def get_data_array(filename):
     f.close()
     return np.frombuffer(str_data, dtype=np.int16),framerate,nchannels
 
+def get_data_array_double(filename):
+    """
+
+    """
+    f = wave.open(filename, "rb")
+    # 读取格式信息
+    # 一次性返回所有的WAV文件的格式信息，它返回的是一个组元(tuple)：声道数, 量化位数（byte单位）, 采样频率, 采样点数, 压缩类型, 压缩类型的描述。wave模块只支持非压缩的数据，因此可以忽略最后两个信息
+    params = f.getparams()
+    nchannels, sampwidth, framerate, nframes = params[:4]
+    # 读取波形数据
+    # 读取声音数据，传递一个参数指定需要读取的长度（以取样点为单位）
+    str_data = f.readframes(nframes)
+    f.close()
+    return np.frombuffer(str_data, dtype=np.int16).astype(np.double),framerate,nchannels
+
+
+
 def get_data_of_ctypes_(inWaveFile=None,int2float=False):
     wavf = wave.open(inWaveFile, 'rb')
     refChannel,refsamWidth,refsamplerate,refframeCount = wavf.getnchannels(),wavf.getsampwidth(),wavf.getframerate(),wavf.getnframes()
