@@ -36,7 +36,7 @@ def cal_delay(reffile, testfile, samplerate):
         return delays.Crude_DelayEst
 
 if __name__ == '__main__':
-       ref = r'D:\AutoWork\audiotestalgorithm\algorithmLib\SNR_ESTIMATION\speech.wav'
-       test = r'D:\AutoWork\audiotestalgorithm\algorithmLib\SNR_ESTIMATION\test.wav'
-       cal_delay(wav2pcm(ref),wav2pcm(test),16000)
+       ref = r'C:\Users\vcloud_avl\Documents\我的POPO\src.wav'
+       test = r'C:\Users\vcloud_avl\Documents\我的POPO\test.wav'
+       cal_delay(wav2pcm(ref),wav2pcm(test),48000)
        pass
\ No newline at end of file
